@@ -36,9 +36,8 @@
 #include <X11/Xatom.h>
 #endif
 
-// #define MAP_SOURCE  OSM_GPS_MAP_SOURCE_OPENSTREETMAP
+/* default values */
 #define MAP_SOURCE  OSM_GPS_MAP_SOURCE_OPENCYCLEMAP
-// #define MAP_SOURCE  OSM_GPS_MAP_SOURCE_GOOGLE_STREET
 #define GPS_DEFAULT_ZOOM 13
 
 #define PROXY_KEY  "/system/http_proxy/"
@@ -425,8 +424,8 @@ on_map_button_release_event(GtkWidget *widget,
       float dist = gpx_pos_get_distance(pos, nearest->pos, FALSE);
       if(dist2pixel(context, dist, nearest->pos.lat) < CLICK_FUZZ) {
 	
-	osm_gps_map_draw_balloon(map, nearest->pos.lat, nearest->pos.lon,
-				 balloon_draw_cb, nearest);
+	osm_gps_map_osd_draw_balloon(map, nearest->pos.lat, nearest->pos.lon,
+				     balloon_draw_cb, nearest);
       }
     }
     context->press_on = NULL;
